__version__ = "0.0.33"
# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00__init__.ipynb.

# %% auto 0
__all__ = []

# %% ../nbs/00__init__.ipynb 3
from itertools import chain
from atyp import (
    bool as bmod, nums, strs, path, enum, byte, type as tmod, imps, insp, logr, clsv, 
    typq, tgrd, iter as imod, list as lmod, sets as smod, rich, plot, typr, 
    data, biol, tens, imgs, cstm,
)

from .bool import *
from .nums import *
from .strs import *
from .path import *
from .enum import *
from .byte import *
from .type import *
from .imps import *
from .insp import *
from .logr import *
from .clsv import *
from .typq import *
from .tgrd import *
from .iter import *
from .list import *
from .sets import *
from .rich import *
from .plot import *
from .typr import *
from .data import *
from .biol import *
from .tens import *
from .imgs import *
from .cstm import *

# %% ../nbs/00__init__.ipynb 4
__all__ = sorted(set(chain(*[
    mod.__all__ for mod in (
        bmod, nums, strs, path, enum, byte, tmod, imps, insp, logr, clsv, 
        typq, tgrd, imod, lmod, smod, rich, plot, typr, data, biol, tens, imgs, cstm,
    )
])))



# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/atyp',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/atyp',
                'lib_path': 'atyp'},
  'syms': { 'atyp.atyp': {},
            'atyp.biol': {},
            'atyp.bool': {},
            'atyp.btyp': {},
            'atyp.byte': {},
            'atyp.clsv': {},
            'atyp.cstm': {},
            'atyp.ctyp': {},
            'atyp.data': {},
            'atyp.dtyp': {},
            'atyp.enum': {},
            'atyp.imgs': {},
            'atyp.imps': {},
            'atyp.insp': {},
            'atyp.iter': {},
            'atyp.ityp': {},
            'atyp.list': {},
            'atyp.logr': {},
            'atyp.mtyp': {},
            'atyp.nums': {},
            'atyp.path': {},
            'atyp.plot': {},
            'atyp.ptyp': {},
            'atyp.qtyp': {},
            'atyp.rich': {},
            'atyp.rtyp': {},
            'atyp.sets': {},
            'atyp.strs': {},
            'atyp.tens': {},
            'atyp.tgrd': {},
            'atyp.type': {},
            'atyp.typq': {},
            'atyp.typr': {},
            'atyp.ztyp': {}}}



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/52_data.ipynb.

# %% auto 0
__all__ = ['NPArray', 'ndarray', 'NPMatrix', 'ndmatrix', 'DataSource', 'Idx', 'Index', 'Series', 'DFrame', 'DataFrame',
           'DataFrames', 'IndexLike', 'SeriesLike', 'IterLike', 'GroupKey', 'SPArray', 'SPMatrix']

# %% ../nbs/52_data.ipynb 6
import inspect
from numbers import Number

# %% ../nbs/52_data.ipynb 8
import types
from typing import (
    Type, TypeAlias, Tuple,
    ClassVar, Any, Optional, Callable, Iterable, ForwardRef
)
from typing import TypeAlias, List, Union, Iterable, List

# %% ../nbs/52_data.ipynb 11
try:
    import numpy as np
    arr = np.ndarray
    mtx = np.matrix
    dsr = np.DataSource
except ImportError:
    # Define a placeholder type if numpy is not installed
    arr = 'np.ndarray'
    mtx = 'np.matrix'
    dsr = 'np.DataSource'

# %% ../nbs/52_data.ipynb 13
try:
    import pandas as pd
    index = pd.Index
    dframe = pd.DataFrame
    series = pd.Series
except ImportError:
    # Define a placeholder type if pandas is not installed
    index = 'pd.Index'    
    dframe = 'pd.DataFrame'
    series = 'pd.Series'

# %% ../nbs/52_data.ipynb 15
try:
    import scipy as sp
    try:
        sparr = sp.sparse._arrays._sparray
    except AttributeError:
        sparr = sp.sparse.sparray
    spmtx = sp.sparse.spmatrix
except ImportError:
    # Define a placeholder type if scipy is not installed
    # sparr = 'sp.sparse.sparray'
    # spmtx = 'sp.sparse.spmatrix'
    sparr = 'scipy.sparse._base.sparray'
    spmtx = 'scipy.sparse._matrix.spmatrix'

# %% ../nbs/52_data.ipynb 17
#| export


# %% ../nbs/52_data.ipynb 19
from .bool import Boolish
from .nums import Numbers
from .tens import Tensor

# %% ../nbs/52_data.ipynb 22
NPArray: TypeAlias = arr
ndarray: TypeAlias = arr
NPMatrix: TypeAlias = mtx
ndmatrix: TypeAlias = mtx
DataSource: TypeAlias = dsr

# %% ../nbs/52_data.ipynb 24
Idx: TypeAlias = index
Index: TypeAlias = index

Series: TypeAlias = series

DFrame: TypeAlias = dframe
DataFrame: TypeAlias = dframe
DataFrames: TypeAlias = List[DataFrame]

# %% ../nbs/52_data.ipynb 26
IndexLike: TypeAlias = Union[Numbers, List[Boolish], Index]
SeriesLike: TypeAlias = Union[list, Series, ndarray, Tensor, IndexLike]
IterLike: TypeAlias = Union[Iterable, SeriesLike, IndexLike]

# %% ../nbs/52_data.ipynb 27
GroupKey: TypeAlias = Union[str, int, float, tuple] # key for pandas groupby

# %% ../nbs/52_data.ipynb 29
SPArray: TypeAlias = sparr
SPMatrix: TypeAlias = spmtx



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/31_typq.ipynb.

# %% auto 0
__all__ = ['AnyQ', 'IntQ', 'SetQ', 'StrQ', 'ObjQ', 'BoolQ', 'DictQ', 'CallQ', 'TypeQ', 'ListQ', 'IterQ', 'FloatQ', 'TupleQ',
           'NumberQ', 'ComplexQ', 'StrLikeQ', 'NumStrQ', 'PttnQ', 'PatternQ', 'LoggerQ', 'ModuleQ', 'PathLikeQ',
           'BoolFuncQ', 'BoolCallQ', 'ClsAnyQ', 'ClsIntQ', 'ClsSetQ', 'ClsStrQ', 'ClsObjQ', 'ClsBoolQ', 'ClsCallQ',
           'ClsTypeQ', 'ClsListQ', 'ClsIterQ', 'ClsFloatQ', 'ClsNumberQ', 'ClsComplexQ', 'IdxQ', 'IndexQ', 'SeriesQ',
           'DataFrameQ', 'NPArrayQ', 'NPMatrixQ', 'SPArrayQ', 'SPMatrixQ', 'DTypeQ', 'DeviceQ', 'TensorQ', 'DatasetQ',
           'DataLoaderQ', 'DataModuleQ', 'VidCapQ', 'ImgSizeQ']

# %% ../nbs/31_typq.ipynb 6
import logging

# %% ../nbs/31_typq.ipynb 8
from typing import (Type, TypeAlias, ClassVar, Any, Optional, Callable, Iterable,)

# %% ../nbs/31_typq.ipynb 10
#| export


# %% ../nbs/31_typq.ipynb 12
#| export


# %% ../nbs/31_typq.ipynb 14
from .bool import Boolish, BoolFunc, BoolCall
from .nums import Numeric, NumStr
from .strs import StrLike, Pttn
from .path import PathLike
from .type import Module
from .data import Idx, Index, Series, DataFrame
from .data import NPArray, NPMatrix, SPArray, SPMatrix

from .imgs import VidCap, ImgSize
from .tens import DType, Device, Tensor, Dataset, DataLoader, DataModule

# %% ../nbs/31_typq.ipynb 17
AnyQ: TypeAlias = Optional[Any]
IntQ: TypeAlias = Optional[int]
SetQ: TypeAlias = Optional[set]
StrQ: TypeAlias = Optional[str]
ObjQ: TypeAlias = Optional[object]

BoolQ: TypeAlias = Optional[Boolish]
DictQ: TypeAlias = Optional[dict]
CallQ: TypeAlias = Optional[Callable]
TypeQ: TypeAlias = Optional[Type]
ListQ: TypeAlias = Optional[list]
IterQ: TypeAlias = Optional[Iterable]
FloatQ: TypeAlias = Optional[float]
TupleQ: TypeAlias = Optional[tuple]
NumberQ: TypeAlias = Optional[Numeric]
ComplexQ: TypeAlias = Optional[complex]

StrLikeQ: TypeAlias = Optional[StrLike]
NumStrQ: TypeAlias = Optional[NumStr]

# %% ../nbs/31_typq.ipynb 19
PttnQ: TypeAlias = Optional[Pttn]
PatternQ: TypeAlias = Optional[Pttn]

# %% ../nbs/31_typq.ipynb 21
LoggerQ: TypeAlias = Optional[logging.Logger]

# %% ../nbs/31_typq.ipynb 23
ModuleQ: TypeAlias = Optional[Module]

PathLikeQ: TypeAlias = Optional[PathLike]

# %% ../nbs/31_typq.ipynb 25
BoolFuncQ: TypeAlias = Optional[BoolFunc]

BoolCallQ: TypeAlias = Optional[BoolCall]

# %% ../nbs/31_typq.ipynb 27
ClsAnyQ = ClassVar[AnyQ]
ClsIntQ = ClassVar[IntQ]
ClsSetQ = ClassVar[SetQ]
ClsStrQ = ClassVar[StrQ]
ClsObjQ = ClassVar[ObjQ]
ClsBoolQ = ClassVar[BoolQ]
ClsCallQ = ClassVar[CallQ]
ClsTypeQ = ClassVar[TypeQ]
ClsListQ = ClassVar[ListQ]
ClsIterQ = ClassVar[IterQ]
ClsFloatQ = ClassVar[FloatQ]
ClsNumberQ = ClassVar[NumberQ]
ClsComplexQ = ClassVar[ComplexQ]

StrLikeQ: TypeAlias = Optional[StrLike]

# %% ../nbs/31_typq.ipynb 29
IdxQ: TypeAlias = Optional[Idx]
IndexQ: TypeAlias = Optional[Index]
SeriesQ: TypeAlias = Optional[Series]
DataFrameQ: TypeAlias = Optional[DataFrame]

# %% ../nbs/31_typq.ipynb 30
NPArrayQ: TypeAlias = Optional[NPArray]
NPMatrixQ: TypeAlias = Optional[NPMatrix]

SPArrayQ: TypeAlias = Optional[SPArray]
SPMatrixQ: TypeAlias = Optional[SPMatrix]

# %% ../nbs/31_typq.ipynb 32
DTypeQ: TypeAlias = Optional[DType]
DeviceQ: TypeAlias = Optional[Device]
TensorQ: TypeAlias = Optional[Tensor]

# %% ../nbs/31_typq.ipynb 33
DatasetQ: TypeAlias = Optional[Dataset]
DataLoaderQ: TypeAlias = Optional[DataLoader]
DataModuleQ: TypeAlias = Optional[DataModule]

# %% ../nbs/31_typq.ipynb 36
VidCapQ: TypeAlias = Optional[VidCap]
ImgSizeQ: TypeAlias = Optional[ImgSize]



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_atyp.ipynb.

# %% auto 0
__all__ = ['Boolic', 'Boolish', 'Bools', 'Numeric', 'Numbers', 'StrLike', 'Strs', 'StrSet', 'StrTmpl', 'PathType', 'PathLike',
           'DirPath', 'DirNames', 'FileNames', 'WalkTuple', 'WalkParts', 'Intum', 'Strum', 'Inhum', 'ByteLike',
           'Literals', 'TypingLike', 'GuardLike', 'Module', 'Loader', 'ModuleSpec', 'Sig', 'Param']

# %% ../nbs/00_atyp.ipynb 4
from typing import (
    TypeAlias, Literal, Union, List, Set,
    Iterable, Tuple, ForwardRef
)

# %% ../nbs/00_atyp.ipynb 7
try: from numpy import bool_ as npbool
except ImportError: npbool = bool

# %% ../nbs/00_atyp.ipynb 8
Boolic:  TypeAlias = Union[bool, npbool]
Boolish: TypeAlias = Union[bool, Boolic, Literal[0], Literal[1]]
Bools:   TypeAlias = List[Boolish]

# %% ../nbs/00_atyp.ipynb 10
from numbers import Number

# %% ../nbs/00_atyp.ipynb 11
Numeric: TypeAlias = Union[int, float, complex, Number]
Numbers: TypeAlias = List[Numeric]

# %% ../nbs/00_atyp.ipynb 13
from string import Template

# %% ../nbs/00_atyp.ipynb 14
StrLike: TypeAlias = Union[str, 'strfix', 'fuzstr', 'nymstr', 'synset']
Strs:    TypeAlias = List[StrLike]
StrSet:  TypeAlias = Set[StrLike]
StrTmpl: TypeAlias = Union[str, Template]

# %% ../nbs/00_atyp.ipynb 16
import os, pathlib

# %% ../nbs/00_atyp.ipynb 17
PathType: TypeAlias = Union[pathlib.Path, pathlib.PosixPath]
PathLike: TypeAlias = Union[str, os.PathLike, pathlib.Path, PathType]

# %% ../nbs/00_atyp.ipynb 19
DirPath:   TypeAlias = PathLike
DirNames:  TypeAlias = List[PathLike]
FileNames: TypeAlias = List[PathLike]
WalkTuple: TypeAlias = Tuple[DirPath, DirNames, FileNames]
WalkParts: TypeAlias = Iterable[WalkTuple]

# %% ../nbs/00_atyp.ipynb 21
# DirLike: TypeAlias = Union['Dir', 'rdir', 'sdir', 'bdir', 'ndir', 'dsrc', 'dtry']
# BaseLike: TypeAlias = Union['Base', 'base',  'bdir', 'btry', 'bpth', 'bsrc', ]
# Entry: TypeAlias = Union[PathLike, 'Entry', 'BaseEntry', 'StructuredEntry', 'ntry']
# BaseType: TypeAlias   = Union[PathLike, Entry, BaseLike, Entry]
# DirType:  TypeAlias   = Union[PathLike, 'StructuredPath', 'DirEntry',  'StructuredDir', DirLike, 'dpath']
# FileType: TypeAlias   = Union[PathLike, 'StructuredPath', 'FileEntry', 'StructuredFile',  'fpath']
# PathType: TypeAlias   = Union[PathLike, 'StructuredPath', 'PathEntry',  Entry,  BaseType, 'ppath']

# %% ../nbs/00_atyp.ipynb 23
from enum import IntEnum, StrEnum

# %% ../nbs/00_atyp.ipynb 24
Intum: TypeAlias = Union[IntEnum, 'LitIntEnum', 'Intum']
Strum: TypeAlias = Union[StrEnum, 'LitStrEnum', 'Strum', 'LiteralEnum']

Inhum = ForwardRef('Inhum', module='inhum', is_class=True)

# %% ../nbs/00_atyp.ipynb 26
ByteLike: TypeAlias = Union[bytes, 'BytesUnit', 'Bytes']

# %% ../nbs/00_atyp.ipynb 28
from typing import TypeVar, TypeGuard

# %% ../nbs/00_atyp.ipynb 29
Literals = TypeVar('Literals')
TypingLike: TypeAlias = Union['TTyp', 'TType', 'TypingUnit', 'Typing']
GuardLike: TypeAlias = Union['TTypGuard', 'TTypeGuard']

# %% ../nbs/00_atyp.ipynb 31
import types

# %% ../nbs/00_atyp.ipynb 32
Module: TypeAlias = types.ModuleType

# %% ../nbs/00_atyp.ipynb 34
import importlib
from importlib.abc import Loader

# %% ../nbs/00_atyp.ipynb 35
Loader: TypeAlias = Loader
ModuleSpec: TypeAlias = importlib.machinery.ModuleSpec

# %% ../nbs/00_atyp.ipynb 37
import inspect

# %% ../nbs/00_atyp.ipynb 38
Sig:   TypeAlias = inspect.Signature
Param: TypeAlias = inspect.Parameter
